@@ -1,5 +1,5 @@
 /*
-@version: 0.3
+@version: 0.4
 @author: Sudheer K. <scifi1947 at gmail.com>
 @license: GNU General Public License
 */
@@ -18,6 +18,8 @@ namespace Ui {
     class ConfigWindow;
 }
 
+class ConfigWindowPrivate;
+
 class ConfigWindow : public QMainWindow {
     Q_OBJECT
 public:
@@ -33,7 +35,7 @@ protected:
 
 private:
     Ui::ConfigWindow *ui;
-    GConfUtility *gconfUtility;
+    ConfigWindowPrivate * const d;
 
 private slots:
     void on_actionReset_triggered();
